uhugo.post_install.detect_providers
===================================

.. automodule:: uhugo.post_install.detect_providers
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members: